@@ -15,9 +15,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -27,10 +27,7 @@
 
 */
 
-extern GtkWidget *main_window_top;		/* Secret base window */
-extern GdkWindow *main_window_gdk;		/* gdk base window */
-
-extern Workspacegroup *main_workspacegroup;	/* All the workspaces */
+extern Workspaceroot *main_workspaceroot;	/* All the workspaces */
 extern Toolkitgroup *main_toolkitgroup;		/* All the toolkits */
 extern Symbol *main_symbol_root;		/* Root of symtable */
 extern Watchgroup *main_watchgroup;		/* All of the watches */
@@ -41,6 +38,7 @@ extern void *main_c_stack_base;			/* Base of C stack */
 extern gboolean main_starting;			/* In startup */
 
 extern gboolean main_option_time_save;		/* Time save image ops */
+extern gboolean main_option_profile;		/* Profile calcualtion */
 extern gboolean main_option_i18n;		/* Output i18n strings */
 extern gboolean main_option_batch;		/* Running in batch mode */
 
@@ -56,5 +54,5 @@ extern GtkStyle *dirty_style;
 
 void main_quit_test( void );
 void main_reload( void );
-gboolean main_load( Workspace *ws, const char *filename );
+const char *get_prefix( void );
 
